@@ -16,7 +16,7 @@
 
 #include <sys/resource.h>
 #include <sys/time.h>
-#if defined(HAVE_SYS_WAIT_H)
+#if HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
 #if HAVE_SYS_PRCTL_H
@@ -58,22 +58,6 @@ const char *Version = PROJECT_VERSION;
 
 // NOTE: if you change the position of the -u switch, be sure to adjust it
 // at the beginning of main()
-#if 0
-// D-BUS has no equivalent
-QByteArray dcopNetworkId()
-{
-    QByteArray result;
-    result.resize(1025);
-    QFile file(DCOPClient::dcopServerFile());
-    if (!file.open(QIODevice::ReadOnly))
-        return "";
-    int i = file.readLine(result.data(), 1024);
-    if (i <= 0)
-        return "";
-    result.data()[i-1] = '\0'; // strip newline
-    return result;
-}
-#endif
 
 static int startApp(QCommandLineParser &p);
 
@@ -165,10 +149,10 @@ int main(int argc, char *argv[])
     int result = startApp(parser);
 
     if (result == 127) {
-        KMessageBox::sorry(nullptr, i18n("Cannot execute command '%1'.", QString::fromLocal8Bit(command)));
+        KMessageBox::error(nullptr, i18n("Cannot execute command '%1'.", QString::fromLocal8Bit(command)));
     }
     if (result == -2) {
-        KMessageBox::sorry(nullptr, i18n("Cannot execute command '%1'. It contains invalid characters.", QString::fromLocal8Bit(command)));
+        KMessageBox::error(nullptr, i18n("Cannot execute command '%1'. It contains invalid characters.", QString::fromLocal8Bit(command)));
     }
 
     return result;
@@ -284,10 +268,7 @@ static int startApp(QCommandLineParser &p)
     bool just_started = false;
     bool have_daemon = true;
     KDEsuClient client;
-    if (!client.isServerSGID()) {
-        qCWarning(category) << "Daemon not safe (not sgid), not using it.\n";
-        have_daemon = false;
-    } else if (client.ping() == -1) {
+    if (client.ping() == -1) {
         if (client.startServer() == -1) {
             qCWarning(category) << "Could not start daemon, reduced functionality.\n";
             have_daemon = false;
